@@ -7,6 +7,24 @@ setMethod("coef", signature(object = "sim"),
 )
 
 
+setMethod("coef", signature(object = "sim.polr"),
+    function(object, slot=c("ALL", "coef", "zeta"))
+    {
+    slot <- match.arg(slot)
+    if(slot=="coef"){
+      ans <- object@coef
+    } else if(slot=="zeta"){
+      ans <- object@zeta
+    } else {
+      ans <- cbind(object@zeta, object@coef)
+    }
+    return(ans)
+    }
+)
+
+
+
+
 
 setMethod("coef", signature(object = "sim.mer"),
     function(object)
